@@ -38,7 +38,7 @@ DEPRECATED = {
 }
 
 
-class CLIArgs:  # pylint: disable=R0902,R0903
+class CLIArgs:  # pylint: disable=R0902
     """Stores the command line arguments passed."""
 
     command: str
@@ -49,6 +49,7 @@ class CLIArgs:  # pylint: disable=R0902,R0903
     files: Optional[str]
     exclude: Optional[str]
     dont_skip_bad_cells: Optional[bool]
+    md: Optional[bool]
 
     def __init__(self, args: argparse.Namespace, cmd_args: Sequence[str]) -> None:
         """
@@ -81,6 +82,7 @@ class CLIArgs:  # pylint: disable=R0902,R0903
             self.skip_celltags = args.nbqa_skip_celltags.split(",")
         else:
             self.skip_celltags = None
+        self.md = args.nbqa_md or None
 
     @staticmethod
     def parse_args(argv: Optional[Sequence[str]]) -> "CLIArgs":
@@ -145,5 +147,14 @@ class CLIArgs:  # pylint: disable=R0902,R0903
                 """
             ),
         )
+        parser.add_argument(
+            "--nbqa-md",
+            action="store_true",
+            help=dedent(
+                r"""
+                Process markdown cells, rather than Python ones.
+                """
+            ),
+        )
         args, cmd_args = parser.parse_known_args(argv)
         return CLIArgs(args, cmd_args)
